@@ -23,7 +23,7 @@ matrix.bigz <- function(data=NA, nrow=1, ncol=1, byrow=FALSE, dimnames=NULL,
 
 as.matrix.bigz <- function(x, ...)
 {
-    if(is.matrix(x) || is.data.frame(x) || inherits(x, "bigz")) {
+    if(is.matrix(x) || is.data.frame(x) || length(dim(x)) == 2L) {
 	d <- dim(x)
 	n <- d[1L]
 	p <- d[2L]
@@ -34,10 +34,14 @@ as.matrix.bigz <- function(x, ...)
     matrix.bigz(x, nrow=n, ncol=p)
 }
 
-
 as.vector.bigz <- function(x, mode="any") {
-  attr(x,"nrow") <- NULL
-  x
+    if(mode == "list") {
+	## "easy"; TODO: gmpToListZ()  withOUT matrix
+	.Call(gmpMatToListZ, matrix.bigz(x, nrow=length(x), ncol=1L), 1L)
+    } else if (mode == "any") {
+	attr(x,"nrow") <- NULL
+	x
+    } else as.vector(as.double(x), mode=mode)
 }
 
 t.bigz <- function(x) .Call(bigint_transposeR, x)
@@ -66,8 +70,13 @@ t.bigz <- function(x) .Call(bigint_transposeR, x)
 
 .dimsetZQ <- function(x,value)
 {
-  stopifnot(value == (v <- as.integer(value)), v >= 0, prod(v) == length(x))
-  attr(x,"nrow") <- v[1]
+  attr(x,"nrow") <-
+    if(is.null(value)) { ## dim(m) <- NULL as in standard R:
+      NULL
+    } else {
+      stopifnot(value == (v <- as.integer(value)), v >= 0, prod(v) == length(x))
+      v[1L]
+    }
   x
 }
 .nrowZQ <- function(x) attr(x,"nrow")
